@@ -1,5 +1,5 @@
 package Courriel::Builder;
-$Courriel::Builder::VERSION = '0.35';
+$Courriel::Builder::VERSION = '0.36';
 use strict;
 use warnings;
 
@@ -454,7 +454,7 @@ Courriel::Builder - Build emails with sugar
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -712,10 +712,6 @@ This creates an email with this structure:
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2014 by Dave Rolsky.
