@@ -1,5 +1,5 @@
 package Courriel::Header::ContentType;
-$Courriel::Header::ContentType::VERSION = '0.35';
+$Courriel::Header::ContentType::VERSION = '0.36';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -92,7 +92,7 @@ Courriel::Header::ContentType - The content type for an email part
 
 =head1 VERSION
 
-version 0.35
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -221,16 +221,12 @@ This class extends L<Courriel::Header>.
 
 =head1 ROLES
 
-This class does the L<Courriel::Role::HeaderWithAttributes> role.
+This class does the C<Courriel::Role::HeaderWithAttributes> role.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2014 by Dave Rolsky.
