@@ -1,5 +1,5 @@
 package Courriel::Part::Multipart;
-$Courriel::Part::Multipart::VERSION = '0.34';
+$Courriel::Part::Multipart::VERSION = '0.36';
 use strict;
 use warnings;
 use namespace::autoclean;
@@ -118,7 +118,7 @@ Courriel::Part::Multipart - A part which contains other parts
 
 =head1 VERSION
 
-version 0.34
+version 0.36
 
 =head1 SYNOPSIS
 
@@ -235,17 +235,13 @@ with "\r\n".
 
 =head1 ROLES
 
-This class does the C<Courriel::Role::Part> and L<Courriel::Role::Streams>
+This class does the C<Courriel::Role::Part> and C<Courriel::Role::Streams>
 roles.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2014 by Dave Rolsky.
